==> zio-aws-securityhub_2.13-5.17.116.1-sources.jar: zio/aws/securityhub/model/AwsElasticsearchDomainElasticsearchClusterConfigZoneAwarenessConfigDetails.scala <==
package zio.aws.securityhub.model
import zio.ZIO
import zio.aws.securityhub.model.primitives.Integer
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class AwsElasticsearchDomainElasticsearchClusterConfigZoneAwarenessConfigDetails(
    availabilityZoneCount: Option[Integer] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.securityhub.model.AwsElasticsearchDomainElasticsearchClusterConfigZoneAwarenessConfigDetails = {
    import AwsElasticsearchDomainElasticsearchClusterConfigZoneAwarenessConfigDetails.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.securityhub.model.AwsElasticsearchDomainElasticsearchClusterConfigZoneAwarenessConfigDetails
      .builder()
      .optionallyWith(
        availabilityZoneCount.map(value =>
          Integer.unwrap(value): java.lang.Integer
        )
      )(_.availabilityZoneCount)
      .build()
  }
  def asReadOnly
      : zio.aws.securityhub.model.AwsElasticsearchDomainElasticsearchClusterConfigZoneAwarenessConfigDetails.ReadOnly =
    zio.aws.securityhub.model.AwsElasticsearchDomainElasticsearchClusterConfigZoneAwarenessConfigDetails
      .wrap(buildAwsValue())
}
object AwsElasticsearchDomainElasticsearchClusterConfigZoneAwarenessConfigDetails {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.securityhub.model.AwsElasticsearchDomainElasticsearchClusterConfigZoneAwarenessConfigDetails
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.securityhub.model.AwsElasticsearchDomainElasticsearchClusterConfigZoneAwarenessConfigDetails =
      zio.aws.securityhub.model
        .AwsElasticsearchDomainElasticsearchClusterConfigZoneAwarenessConfigDetails(
          availabilityZoneCount.map(value => value)
        )
    def availabilityZoneCount: Option[Integer]
    def getAvailabilityZoneCount: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("availabilityZoneCount", availabilityZoneCount)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.securityhub.model.AwsElasticsearchDomainElasticsearchClusterConfigZoneAwarenessConfigDetails
  ) extends zio.aws.securityhub.model.AwsElasticsearchDomainElasticsearchClusterConfigZoneAwarenessConfigDetails.ReadOnly {
    override val availabilityZoneCount: Option[Integer] = scala
      .Option(impl.availabilityZoneCount())
      .map(value => zio.aws.securityhub.model.primitives.Integer(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.securityhub.model.AwsElasticsearchDomainElasticsearchClusterConfigZoneAwarenessConfigDetails
  ): zio.aws.securityhub.model.AwsElasticsearchDomainElasticsearchClusterConfigZoneAwarenessConfigDetails.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-securityhub_2.13-5.17.148.1-sources.jar: zio/aws/securityhub/model/AwsElasticsearchDomainElasticsearchClusterConfigZoneAwarenessConfigDetails.scala <==
package zio.aws.securityhub.model
import zio.ZIO
import zio.aws.securityhub.model.primitives.Integer
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class AwsElasticsearchDomainElasticsearchClusterConfigZoneAwarenessConfigDetails(
    availabilityZoneCount: Option[Integer] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.securityhub.model.AwsElasticsearchDomainElasticsearchClusterConfigZoneAwarenessConfigDetails = {
    import AwsElasticsearchDomainElasticsearchClusterConfigZoneAwarenessConfigDetails.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.securityhub.model.AwsElasticsearchDomainElasticsearchClusterConfigZoneAwarenessConfigDetails
      .builder()
      .optionallyWith(
        availabilityZoneCount.map(value => value: java.lang.Integer)
      )(_.availabilityZoneCount)
      .build()
  }
  def asReadOnly
      : zio.aws.securityhub.model.AwsElasticsearchDomainElasticsearchClusterConfigZoneAwarenessConfigDetails.ReadOnly =
    zio.aws.securityhub.model.AwsElasticsearchDomainElasticsearchClusterConfigZoneAwarenessConfigDetails
      .wrap(buildAwsValue())
}
object AwsElasticsearchDomainElasticsearchClusterConfigZoneAwarenessConfigDetails {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.securityhub.model.AwsElasticsearchDomainElasticsearchClusterConfigZoneAwarenessConfigDetails
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.securityhub.model.AwsElasticsearchDomainElasticsearchClusterConfigZoneAwarenessConfigDetails =
      zio.aws.securityhub.model
        .AwsElasticsearchDomainElasticsearchClusterConfigZoneAwarenessConfigDetails(
          availabilityZoneCount.map(value => value)
        )
    def availabilityZoneCount: Option[Integer]
    def getAvailabilityZoneCount: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("availabilityZoneCount", availabilityZoneCount)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.securityhub.model.AwsElasticsearchDomainElasticsearchClusterConfigZoneAwarenessConfigDetails
  ) extends zio.aws.securityhub.model.AwsElasticsearchDomainElasticsearchClusterConfigZoneAwarenessConfigDetails.ReadOnly {
    override val availabilityZoneCount: Option[Integer] =
      scala.Option(impl.availabilityZoneCount()).map(value => value: Integer)
  }
  def wrap(
      impl: software.amazon.awssdk.services.securityhub.model.AwsElasticsearchDomainElasticsearchClusterConfigZoneAwarenessConfigDetails
  ): zio.aws.securityhub.model.AwsElasticsearchDomainElasticsearchClusterConfigZoneAwarenessConfigDetails.ReadOnly =
    new Wrapper(impl)
}
